bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaISO.get_moments
=======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGammaISO.get_moments